[commit: ghc] ghc-parmake-gsoc: Rename DynFlags.parUpsweepNum to parMakeCount (1c33153)

git at git.haskell.org git at git.haskell.org
Sat Aug 31 02:27:06 CEST 2013


Repository : ssh://git@git.haskell.org/ghc

On branch  : ghc-parmake-gsoc
Link       : http://ghc.haskell.org/trac/ghc/changeset/1c3315341a41accdc6b31a492132be0fab681a5c/ghc

>---------------------------------------------------------------

commit 1c3315341a41accdc6b31a492132be0fab681a5c
Author: Patrick Palka <patrick at parcs.ath.cx>
Date:   Fri Aug 30 12:57:12 2013 -0400

    Rename DynFlags.parUpsweepNum to parMakeCount


>---------------------------------------------------------------

1c3315341a41accdc6b31a492132be0fab681a5c
 compiler/main/DynFlags.hs |    8 ++++----
 compiler/main/GhcMake.hs  |    2 +-
 2 files changed, 5 insertions(+), 5 deletions(-)

diff --git a/compiler/main/GhcMake.hs b/compiler/main/GhcMake.hs
index 5fc21f3..3581aa0 100644
--- a/compiler/main/GhcMake.hs
+++ b/compiler/main/GhcMake.hs
@@ -270,7 +270,7 @@ load how_much = do
     liftIO $ debugTraceMsg dflags 2 (hang (text "Ready for upsweep")
                                2 (ppr mg))
 
-    n_jobs <- case parUpsweepNum dflags of
+    n_jobs <- case parMakeCount dflags of
                     Nothing -> liftIO getNumProcessors
                     Just n  -> return n
     let upsweep_fn | n_jobs > 1 = parUpsweep n_jobs





More information about the ghc-commits mailing list
diff --git a/compiler/main/DynFlags.hs b/compiler/main/DynFlags.hs
index 37b016b..1fca713 100644
--- a/compiler/main/DynFlags.hs
+++ b/compiler/main/DynFlags.hs
@@ -582,8 +582,8 @@ data DynFlags = DynFlags {
   ruleCheck             :: Maybe String,
   strictnessBefore      :: [Int],       -- ^ Additional demand analysis
 
-  parUpsweepNum         :: Maybe Int,   -- ^ The number of modules to compile in parallel
-                                        --   during the upsweep, where Nothing ==> compile as
+  parMakeCount          :: Maybe Int,   -- ^ The number of modules to compile in parallel
+                                        --   in --make mode, where Nothing ==> compile as
                                         --   many in parallel as there are CPUs.
 
   maxRelevantBinds      :: Maybe Int,   -- ^ Maximum number of bindings from the type envt
@@ -1270,7 +1270,7 @@ defaultDynFlags mySettings =
         historySize             = 20,
         strictnessBefore        = [],
 
-        parUpsweepNum           = Just 1,
+        parMakeCount            = Just 1,
 
         cmdlineHcIncludes       = [],
         importPaths             = ["."],
@@ -2030,7 +2030,7 @@ dynamic_flags = [
                            addWarn "-#include and INCLUDE pragmas are deprecated: They no longer have any effect"))
   , Flag "v"        (OptIntSuffix setVerbosity)
 
-  , Flag "j"        (OptIntSuffix (\n -> upd (\d -> d {parUpsweepNum = n})))
+  , Flag "j"        (OptIntSuffix (\n -> upd (\d -> d {parMakeCount = n})))
 
         ------- ways --------------------------------------------------------
   , Flag "prof"           (NoArg (addWay WayProf))